#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for Pari/GP
#---( Home Page: http://pari.math.u-bordeaux.fr/
#---( Source: http://pari.math.u-bordeaux.fr/pub/pari/unix/pari-2.3.4.tar.gz
#---( Author: R S Ananda Murthy (rsamurti@gmail.com)
#---( Date build script was last modified: Tuesday, 25-August-2009.


#------------------( Set Package Name & Version )


soft='pari'
softversion='2.3.4'
packageversion='62.1'
sourcetemplate='http://zenwalk.pinguix.com/user-accounts/rsamurti/pari'


#------------------( Check for source file )


if [ -f $soft-$softversion.tar.gz  ]; then
   echo "Source file .. ok"
else
   echo "Source file does not exit. Downloading it ..."
   wget -c http://pari.math.u-bordeaux.fr/pub/pari/unix/pari-2.3.4.tar.gz
fi


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships and CFLAGS, CXXFLAGS and FFLAGS )


chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
export FFLAGS="-O2 -march=i486 -mtune=i686"


#------------------( Configure, Make And Install The Software )


cd $src

./Configure --prefix=/usr --mandir=/usr/man --with-gmp
make all
make bench
make docpdf
make install DESTDIR=$dest


#------------------( Strip Executables (Comment out these lines if debugging info is needed) )


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)


#------------------( Compress Man Pages and Info Pages and Move To Correct Location )


( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)


#------------------( Move Documentation To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion

cp -a \
  Announce.* AUTHORS CHANGES.* COPYING COMPAT CVS.txt MACHINES README.* INSTALL \
  $dest/usr/doc/$soft-$softversion
mv $dest/usr/share/pari/doc/* $dest/usr/doc/$soft-$softversion
mv $dest/usr/share/pari/examples $dest/usr/doc/$soft-$softversion
rm -r $dest/usr/share/pari/doc
mv $src/doc/*.pdf $dest/usr/doc/$soft-$softversion


#------------------( Copy The Build Script for Future Use )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( We Made A Custom Icon, Let's Copy It For Next Time )


cp $buildir/$soft.png $dest/usr/src/$soft-$softversion/$soft.png
chmod -x $dest/usr/src/$soft-$softversion/$soft.png


#------------------( Copy gprc.dft file to the /etc directory )


mkdir -p $dest/etc
cp $src/misc/gprc.dft $dest/etc/gprc


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc
    |-----handy-ruler------------------------------------------------------|
pari: Pari/GP (A computer algebra system)
pari: 
pari: PARI/GP is a widely used computer algebra system designed for fast
pari: computations in number theory (factorizations, algebraic number
pari: theory, elliptic curves...), but also contains a large number
pari: of other useful functions to compute with mathematical entities
pari: such as matrices, polynomials, power series, algebraic numbers, etc.,
pari: and a lot of transcendental functions.
pari: 
pari: 
pari: 
EOF


#------------------( Create The SRC File )


if [ -f $buildir/$package.src  ]; then
rm $package.src
fi
cat <<EOF > $buildir/$package.src
$sourcetemplate/build-$soft.sh
$sourcetemplate/$soft.$softversion.tar.gz
$sourcetemplate/$soft.png
EOF



#------------------( Create The Desktop Menu Entry and Remove Defective Desktop File )


mkdir -p $dest/usr/share/applications
cat <<EOF > $dest/usr/share/applications/$soft.desktop
[Desktop Entry]
Name=PARI/GP
Comment=Programmable calculator based on PARI
Exec=gp
Icon=pari
Terminal=true
Type=Application
Categories=Application;Education;Math;Scientific;
Encoding=UTF-8
StartupNotify=true
EOF


#------------------( Copy The Icon To The Correct Location )


mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
cp $buildir/$soft.png $dest/usr/share/icons/hicolor/48x48/apps/$soft.png
chmod -x $dest/usr/share/icons/hicolor/48x48/apps/$soft.png


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest

find . -perm 640 -exec chmod 644 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 700 -exec chmod 755 {} \;
find . -perm 770 -exec chmod 755 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n ../$package.tlz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tlz > $package.md5
zen-pkgcheck.pl $package.tlz
depfinder -f $package.tlz > $package.dep
